math
====

.. autofunction:: e3nn.math.direct_sum

.. autofunction:: e3nn.math.orthonormalize

.. autofunction:: e3nn.math.complete_basis

.. autofunction:: e3nn.math.soft_one_hot_linspace

.. autofunction:: e3nn.math.soft_unit_step
